from distutils.core import setup

setup(name='iterm2_image',
      version='0.1',
      py_modules=['iterm2_image'],
      description='Prints images and sends files using the iTerm2 image extension',
      author='zakx',
      author_email='zakx@koeln.ccc.de',
      url='https://github.com/zakx/iterm2_image',
      classifiers=[
          'Development Status :: 4 - Beta',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          ],
      )
